/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2010 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: ConfigurationVO.as 20254 2010-09-03 13:17:32Z skabore $
 * --------------------------------------------------------------------------
 */
package org.ow2.jonas.admin.autostart.model {

import com.adobe.cairngorm.model.ModelLocator;

import mx.controls.Alert;
import mx.controls.Button;
import mx.controls.List;
import mx.controls.ProgressBar;
import mx.utils.UIDUtil;

import org.ow2.jonas.admin.autostart.business.*;
import org.ow2.jonas.admin.autostart.view.MainView;
import org.ow2.jonas.admin.autostart.vo.*;

import mx.controls.TextArea;
import mx.collections.ArrayCollection;

import org.ow2.jonas.admin.autostart.vo.configuration.AdvancedJDBCConfigurationVO;
import org.ow2.jonas.admin.autostart.vo.configuration.JDBCConfigurationVO;

/**
 * The model locator for the Builder.
 */
[Bindable]
public class BuilderModelLocator implements ModelLocator {

    private var builderDelegate:BuilderDelegate = null;

    private var builderVObj:BuilderVO = new BuilderVO();

    private var buildStatusObj:String = "Error";

    private var jonasSelectedVersionObj:String;

    private var jonasSelectedTypeObj:String;

    private var jonasZipFileObj:String;

    private var downloadFileObj:String;

    private var getJonasFromObj:int;

    private var isValidUrlObj:Boolean;

    public var jonasRoot:String;

    public var jonasBase:String;

    private var date:Date = new Date();

    private var month:uint = date.getMonth() + 1;

    private var id:String = "_" +
            date.getDate() + month + date.getFullYear()
            + date.getHours() + date.getMinutes() + date.getSeconds();

    private var jonasStarterNameObj:String = "jonas-starter" + id + ".jar";

    private var jonasStarterDescriptionObj:String = "";

	[ArrayElementType("org.ow2.jonas.admin.autostart.vo.StarterVO")]
    private var jonasStarterListObj:ArrayCollection = new ArrayCollection();

	[ArrayElementType("String")]
    private var uploadedApplicationObj:ArrayCollection = new ArrayCollection();

	[ArrayElementType("String")]
    private var availableApplicationObj:ArrayCollection = new ArrayCollection();

	[ArrayElementType("String")]
    private var jonasVersionsObj:ArrayCollection = new ArrayCollection();

	[ArrayElementType("String")]
    private var jonasServicesObj:ArrayCollection = new ArrayCollection();

	[ArrayElementType("String")]
    private var jonasSelectedServicesObj:ArrayCollection = new ArrayCollection();

    public var applyConfiguration:Boolean = false;

    public var useFullStarter:Boolean = false;

    public var includeJonasClient:Boolean = false;

    private var outputTextObj:String = "";

	[ArrayElementType("String")]
    public var outputValue:ArrayCollection = new ArrayCollection();

    public var btnNextForApplicationSate:Button = new Button();

    public var btnNextForGettingJonasFieldsSate:Button = new Button();

    public var btnNextForBuildProcessSummarySate:Button = new Button();

    public var btnNextForBuildProcessSate:Button = new Button();

    public var outputList:List = new List();

    public var progressBar:ProgressBar = new ProgressBar();

    private var mainViewObj:MainView = null;


    /**
     * Configuration values.
     */

    public var httpPort:String = "9000";

    public var redirectPort:String = "0";

    public var useSsl:Boolean = false;

    public var activateJvmRoute:Boolean = false;

    public var protocolList:ArrayCollection = new ArrayCollection();

    public var jrmpPort:String = "rmi://localhost:1099";

    public var irmiPort:String = "rmi://localhost:1098";

    public var iiopPort:String = "iiop://localhost:2001";

    public var lmiPort:String = "rmi://localhost:0";

	[ArrayElementType("String")]
    public var servicesList:ArrayCollection = new ArrayCollection();

    public var jmsPort:String = "16010";

	[ArrayElementType("String")]
    public var queueList:ArrayCollection = new ArrayCollection();

	[ArrayElementType("String")]
    public var topicList:ArrayCollection = new ArrayCollection();

    public var dbPort:String = "9001";

    public var dbName:String = "db_jonas";

    public var dbUser:String = "jonas";

    public var dbUserpasswd:String = "jonas";

    public var jdbcConfiguration:JDBCConfigurationVO = new JDBCConfigurationVO();

    ////////////////////////////////////
    //                                //
    //             Functions          //
    //                                //
    ////////////////////////////////////
    public function BuilderModelLocator() {
        super();
        builderVObj = new BuilderVO();
        jdbcConfiguration.rarLink = "--select an item--";
        jdbcConfiguration.advancedJDBCConfiguration.checkingLevel = "--select an item--";
    }


    ////////////////////////////////////
    //                                //
    //             Setters            //
    //                                //
    ////////////////////////////////////
    public function set builderVO(builderVO:BuilderVO):void {
        this.builderVObj = builderVO;
    }

    public function set buildStatus(buildStatus:String):void {
        this.buildStatusObj = buildStatus;
    }

    public function set jonasSelectedVersion(jonasSelectedVersion:String):void {
        this.jonasSelectedVersionObj = jonasSelectedVersion;
    }

    public function set jonasSelectedType(jonasSelectedType:String):void {
        this.jonasSelectedTypeObj = jonasSelectedType;
    }

    public function set jonasZipFile(jonasZipFile:String):void {
        this.jonasZipFileObj = jonasZipFile;
    }

    public function set downloadFile(downloadFile:String):void {
        this.downloadFileObj = downloadFile;
    }

    public function set jonasStarterName(jonasStarterName:String):void {
        this.jonasStarterNameObj = jonasStarterName;
    }

    public function set jonasStarterDescription(jonasStarterDescription:String):void {
        this.jonasStarterDescriptionObj = jonasStarterDescription;
    }

    public function set jonasStarterList(jonasStarterList:ArrayCollection):void {
        this.jonasStarterListObj = jonasStarterList;
    }

    public function set availableApplication(availableApplication:ArrayCollection):void {
        this.availableApplicationObj = availableApplication;
    }

    public function set uploadedApplication(uploadedApplication:ArrayCollection):void {
        this.uploadedApplicationObj = uploadedApplication;
    }

    public function set jonasVersions(jonasVersions:ArrayCollection):void {
        this.jonasVersionsObj = jonasVersions;
    }

    public function set jonasServices(jonasServices:ArrayCollection):void {
        this.jonasServicesObj = jonasServices;
    }

    public function set jonasSelectedServices(jonasSelectedServices:ArrayCollection):void {
        this.jonasSelectedServicesObj = jonasSelectedServices;
    }

    public function set getJonasFrom(getJonasFrom:int):void {
        this.getJonasFromObj = getJonasFrom;
    }

    public function set outputText(output:String):void {
        this.outputTextObj = output;
    }

    public function set isValidUrl(isValidUrl:Boolean):void {
        this.isValidUrlObj = isValidUrl;
    }

    public function set view(mainView:MainView):void {
        this.mainViewObj = mainView;
    }

    ////////////////////////////////////
    //                                //
    //             Getters            //
    //                                //
    ////////////////////////////////////
    public function get builderVO():BuilderVO {
        return this.builderVObj;
    }

    public function get buildStatus():String {
        return this.buildStatusObj;
    }

    public function get jonasSelectedVersion():String {
        return this.jonasSelectedVersionObj;
    }

    public function get jonasSelectedType():String {
        return this.jonasSelectedTypeObj;
    }

    public function get jonasZipFile():String {
        return this.jonasZipFileObj;
    }

    public function get downloadFile():String {
        return this.downloadFileObj;
    }

    public function get jonasStarterName():String {
        return this.jonasStarterNameObj;
    }

    public function get jonasStarterDescription():String {
        return this.jonasStarterDescriptionObj;
    }

    public function get jonasStarterList():ArrayCollection {
        return this.jonasStarterListObj;
    }

    public function get uploadedApplication():ArrayCollection {
        return this.uploadedApplicationObj;
    }


    public function get availableApplication():ArrayCollection {
        return this.availableApplicationObj;
    }

    public function get jonasVersions():ArrayCollection {
        return this.jonasVersionsObj;
    }

    public function get jonasServices():ArrayCollection {
        return this.jonasServicesObj;
    }

    public function get jonasSelectedServices():ArrayCollection {
        return this.jonasSelectedServicesObj;
    }

    public function get getJonasFrom():int {
        return this.getJonasFromObj;
    }

    public function get outputText():String {
        return this.outputTextObj;
    }

    public function get isValidUrl():Boolean {
        return this.isValidUrlObj;
    }

    public function get view():MainView {
        return this.mainViewObj;
    }


    public function getDelegate():BuilderDelegate {
        if (this.builderDelegate == null) {
            this.builderDelegate = new BuilderDelegate();
        }
        return this.builderDelegate;
    }
}
}
